@@ -8,7 +8,7 @@ could use:
 qtawesome is an optional dependency, it is disabled by default.
 If your application use qtawesome, just set ``USE_QTAWESOME`` to True.
 """
-from pyqode.qt import QtGui
+from qtpy import QtGui
 try:
     import qtawesome as qta
 except ImportError:
@@ -59,4 +59,4 @@ def icon(theme_name='', path='', qta_name='', qta_options=None, use_qta=None):
             ret_val = QtGui.QIcon(path)
     if ret_val is None:
         ret_val = QtGui.QIcon.fromTheme('image-missing')
-    return ret_val
+    return ret_val
\ No newline at end of file
