@@ -1,7 +1,7 @@
 """
 This module contains the smart backspace mode
 """
-from pyqode.qt.QtCore import Qt
+from qtpy.QtCore import Qt
 from pyqode.core.api import Mode
 
 
@@ -231,4 +231,4 @@ class SmartBackSpaceMode(Mode):
             selected_text,
             selected_text.isspace() and selected_text,
             cursor.block().text() == selected_text
-        )
+        )
\ No newline at end of file
