@@ -2,7 +2,7 @@
 """
 This module contains the breakpoints checker mode
 """
-from pyqode.qt import QtCore, QtGui
+from qtpy import QtCore, QtGui
 from pyqode.core.modes import CheckerMode, CheckerMessage, CheckerMessages
 
 
@@ -85,4 +85,4 @@ class BreakpointMode(CheckerMode):
         else:
             self._breakpoints[path].append(line)
         self.request_analysis()
-        self.breakpoint_toggled.emit(path, line)
+        self.breakpoint_toggled.emit(path, line)
\ No newline at end of file
