@@ -8,7 +8,7 @@ import sys
 import time
 from pyqode.core.api.mode import Mode
 from pyqode.core.backend import NotRunning
-from pyqode.qt import QtWidgets, QtCore, QtGui
+from qtpy import QtWidgets, QtCore, QtGui
 from pyqode.core.api.utils import TextHelper
 from pyqode.core import backend
 
@@ -25,6 +25,7 @@ NAVIGATION_KEYS = (
     QtCore.Qt.Key_Space
 )
 MIN_WIDTH = 200
+icon_cache = {}
 
 
 def _logger():
@@ -374,7 +375,7 @@ class CodeCompletionMode(Mode, QtCore.QObject):
         def _handle_completer_events():
             nav_key = self._is_navigation_key(event)
             mod = QtCore.Qt.ControlModifier
-            ctrl = int(event.modifiers() & mod) == mod
+            ctrl = event.modifiers() == mod
             # complete
             if event.key() in [
                     QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return,
@@ -432,7 +433,7 @@ class CodeCompletionMode(Mode, QtCore.QObject):
             elif len(word) >= self._trigger_len and event.text() not in \
                     self.editor.word_separators:
                 # Length trigger
-                if int(event.modifiers()) in [
+                if event.modifiers() in [
                         QtCore.Qt.NoModifier, QtCore.Qt.ShiftModifier]:
                     self.request_completion()
                 else:
@@ -563,7 +564,7 @@ class CodeCompletionMode(Mode, QtCore.QObject):
         """
         modifier = (QtCore.Qt.MetaModifier if sys.platform == 'darwin' else
                     QtCore.Qt.ControlModifier)
-        valid_modifier = int(event.modifiers() & modifier) == modifier
+        valid_modifier = event.modifiers() == modifier
         valid_key = event.key() == self._trigger_key
         return valid_key and valid_modifier
 
@@ -673,6 +674,20 @@ class CodeCompletionMode(Mode, QtCore.QObject):
     def _show_completions(self, completions):
         self._update_model(completions)
         self._show_popup()
+        
+    def _icon(self, name):
+        if isinstance(name, list):
+            name, fallback = name
+        else:
+            fallback = None
+        if name in icon_cache:
+            return icon_cache[name]
+        if fallback is None:
+            icon = QtGui.QIcon(name)
+        else:
+            icon = QtGui.QIcon.fromTheme(name, self._icon(fallback))
+        icon_cache[name] = icon
+        return icon
 
     def _update_model(self, completions):
         """
@@ -695,12 +710,7 @@ class CodeCompletionMode(Mode, QtCore.QObject):
             if 'tooltip' in completion and completion['tooltip']:
                 self._tooltips[name] = completion['tooltip']
             if 'icon' in completion:
-                icon = completion['icon']
-                if isinstance(icon, list):
-                    icon = QtGui.QIcon.fromTheme(icon[0], QtGui.QIcon(icon[1]))
-                else:
-                    icon = QtGui.QIcon(icon)
-                item.setData(QtGui.QIcon(icon),
+                item.setData(self._icon(completion['icon']),
                              QtCore.Qt.DecorationRole)
             cc_model.appendRow(item)
         try:
