@@ -8,7 +8,7 @@ Checker panels:
 from pyqode.core import icons
 from pyqode.core.api import DelayJobRunner, TextHelper
 from pyqode.core.api.panel import Panel
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 
 
 class CheckerPanel(Panel):
@@ -162,4 +162,4 @@ class CheckerPanel(Panel):
         widget.move(self.mapToGlobal(QtCore.QPoint(-widget.width(), top)))
 
     def _message_count(self, n):
-        pass
+        pass
\ No newline at end of file
