@@ -9,7 +9,7 @@ from pyqode.core.api import TextBlockHelper, folding, TextDecoration, \
     DelayJobRunner
 from pyqode.core.api.folding import FoldScope
 from pyqode.core.api.panel import Panel
-from pyqode.qt import QtCore, QtWidgets, QtGui, PYQT5_API
+from qtpy import QtCore, QtWidgets, QtGui, PYQT5_API
 from pyqode.core.api.utils import TextHelper, drift_color
 
 NAVIGATION_KEYS = (
@@ -353,10 +353,7 @@ class FoldingPanel(Panel):
         rect = QtCore.QRect(0, top, self.sizeHint().width(),
                             self.sizeHint().height())
         if self._native:
-            if os.environ['QT_API'].lower() not in PYQT5_API:
-                opt = QtGui.QStyleOptionViewItemV2()
-            else:
-                opt = QtWidgets.QStyleOptionViewItem()
+            opt = QtWidgets.QStyleOptionViewItem()
             opt.rect = rect
             opt.state = (QtWidgets.QStyle.State_Active |
                          QtWidgets.QStyle.State_Item |
