@@ -5,7 +5,7 @@ import locale
 import logging
 from pyqode.core import icons
 from pyqode.core.api import ENCODINGS_MAP, convert_to_codec_key
-from pyqode.qt import QtCore, QtWidgets
+from qtpy import QtCore, QtWidgets
 from pyqode.core.cache import Cache
 
 
@@ -194,4 +194,4 @@ class EncodingsContextMenu(EncodingsMenu):
             except KeyError:
                 pass
             else:
-                panel.close_panel()
+                panel.close_panel()
\ No newline at end of file
